/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Acpi.h"
#include "Debug.h"
#include "XmlOptions.h"

namespace Acpi
{

    //____________________________________________________________________________
    Acpi::Acpi():
        process_( this )
    {
        Debug::Throw( "Acpi::Acpi.\n" );
        connect( &process_, SIGNAL(finished(int,QProcess::ExitStatus)), SLOT(_commandCompleted(int,QProcess::ExitStatus)) );
        setThreshold( Low, 25 );
        setThreshold( Critical, 10 );
    }


    //__________________________________________________
    void Acpi::update()
    {

        Debug::Throw( "Acpi::update.\n" );
        if( process_.state() == QProcess::NotRunning )
        { process_.start( QString( XmlOptions::get().raw( "ACPI" ) ).split( " " ) ); }

        return;
    }

    //__________________________________________________
    void Acpi::_commandCompleted( int code, QProcess::ExitStatus status )
    {

        // check exit status
        Debug::Throw() << "Acpi::_commandCompleted -"
            << " code: " << code
            << " status: " << status
            << endl;

        QString output( process_.readAllStandardOutput() );
        if( !output.isNull() )
        {

            bool changed = false;
            const auto stringList( output.split( QRegExp("(: )|,|%") ) );
            if( stringList.size() >= 3 )
            {

                stateText_ = stringList[1];

                if( !( stateText_.compare( "charged", Qt::CaseInsensitive ) && stateText_.compare( "full", Qt::CaseInsensitive ) ) ) changed |= _setState( Charged );
                else if( !stateText_.compare( "charging", Qt::CaseInsensitive ) ) changed |= _setState( Charging );
                else if( !stateText_.compare( "discharging", Qt::CaseInsensitive ) ) changed |= _setState( Discharging );
                else changed |= _setState( Unknown );

                changed |= _setProgress( stringList[2].toUInt() );
                if( progress() <= thresholds_[Critical] ) changed |= _setLevel( Critical );
                else if( progress() <= thresholds_[Low] ) changed |= _setLevel( Low );
                else changed |= _setLevel( Normal );

                if( stringList.size() > 3 ) { tooltipText_ = stringList.back(); }

            } else {

                // could not parse string list. Set state to unknown.
                changed |= _setState( Unknown );

            }

            if( changed ) emit updated();

        }


    }

}
