#ifndef Acpi_h
#define Acpi_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CustomProcess.h"

#include <QObject>
#include <QProcess>
#include <QHash>


//* battery monitor
namespace Acpi
{

    //* display a set of log entries, allows selection of one
    class Acpi: public QObject
    {

        Q_OBJECT

        public:

        //* constructor
        explicit Acpi();

        //* battery state
        enum State
        {
            Unknown,
            Charged,
            Charging,
            Discharging
        };

        //* battery level
        enum Level
        {
            Normal,
            Low,
            Critical
        };

        //* battery state
        State state() const
        { return state_; }

        //* battery level
        Level level() const
        { return level_; }

        //* state text
        const QString& stateText() const
        { return stateText_; }

        //* tooltip text
        const QString& tooltipText() const
        { return tooltipText_; }

        //* progress
        int progress() const
        { return progress_; }

        //* threshold
        void setThreshold( Level level, int value )
        { thresholds_[level] = value; }

        Q_SIGNALS:

        void updated();

        public Q_SLOTS:

        //* update all dataSamples from file
        void update();

        private Q_SLOTS:

        //* update
        void _commandCompleted( int, QProcess::ExitStatus status );

        private:

        //* battery state
        bool _setState( State value, bool forced = false )
        {
            if( value == state_ && !forced ) return false;
            state_ = value;
            return true;
        }

        //* battery level
        bool _setLevel( Level value , bool forced = false )
        {
            if( value == level_ && !forced ) return false;
            level_ = value;
            return true;
        }

        //* progress
        bool _setProgress( int value, bool forced = false )
        {
            if( value == progress_ && !forced ) return false;
            progress_ = value;
            return true;
        }

        //* process
        CustomProcess process_;

        //* current state
        State state_ = Unknown;

        //* current level
        Level level_ = Normal;

        //* progress
        int progress_ = 0;

        //* state text
        QString stateText_;

        //* tooltip
        QString tooltipText_;

        // threshold
        using ThresholdMap = QHash< Level, int >;
        ThresholdMap thresholds_;

    };

}

#endif
