#ifndef CalendarEventDialog_h
#define CalendarEventDialog_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CalendarEventModel.h"
#include "CustomDialog.h"

#include <QPushButton>
#include <QAction>

class TreeView;

namespace Calendar
{

    //* Edit/create alarms
    class CalendarEventDialog: public CustomDialog
    {


        //* Qt meta object declaration
        Q_OBJECT

        public:

        //* constructor
        explicit CalendarEventDialog( QWidget* parent, const CalendarEvent::List& list = CalendarEvent::List() );

        //* alarm list
        void setList( const CalendarEvent::List& list );

        //* alarm list
        CalendarEvent::List list() const;

        private Q_SLOTS:

        //* update buttons
        void _updateButtons();

        //* add a value
        void _add();

        //* add a value
        void _edit();

        //* remove a value
        void _remove();

        //* import
        void _import();

        //* export
        void _export();

        private:

        //* model
        CalendarEventModel model_;

        //* alarm list
        TreeView* list_ = nullptr;

        //* edit button
        QPushButton* edit_ = nullptr;

        //* remove button
        QPushButton* remove_ = nullptr;

        //* edit action
        QAction* editAction_ = nullptr;

        //* remove action
        QAction* removeAction_ = nullptr;

        //* export button
        QPushButton* export_ = nullptr;

    };

};

#endif
