#ifndef CalendarPath_h
#define CalendarPath_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"

#include <QColor>
#include <QList>
#include <QRectF>

namespace Calendar
{
    //* local path
    class Path final: private Base::Counter<Path>
    {
        public:

        //* constructor
        explicit Path( const QRectF& rect = QRectF(), const QColor& color = QColor() ):
            Counter( "Calendar::Path" ),
            rect_( rect ),
            color_( color )
        {}

        //*@name accessors
        //@{

        //* rectangle
        const QRectF& rect() const
        { return rect_; }

        //* color
        const QColor& color() const
        { return color_; }

        //@}

        //*@name modifiers
        //@{

        //* rectangle
        void setRect( const QRectF& rect )
        { rect_ = rect; }

        //* color
        void setColor( const QColor& color )
        { color_ = color; }

        //@}

        //* shortcut to PainterPath list
        using List = QList<Path>;

        private:

        //* rect
        QRectF rect_;

        //* color
        QColor color_;

    };
}

#endif
