#ifndef AlarmListDialog_h
#define AlarmListDialog_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

/**
\file AlarmListDialog.h
\brief Edit/create alarms
\author Hugo Pereira
\version $Revision$
\date $Date$
*/

#include "AlarmModel.h"
#include "CustomDialog.h"

#include <QPushButton>
#include <QAction>

class TreeView;

namespace Clock
{
    //* Edit/create alarms
    class AlarmListDialog: public CustomDialog
    {

        Q_OBJECT

        public:

        //* constructor
        explicit AlarmListDialog( QWidget*, const Alarm::List& = Alarm::List() );

        //* alarm list
        void setList( const Alarm::List& );

        //* alarm list
        Alarm::List list() const;

        private Q_SLOTS:

        //* toggle alarm enabled state
        void _toggle( const QModelIndex& );

        //* update buttons
        void _updateButtons();

        //* add a value
        void _add();

        //* add a value
        void _edit();

        //* remove a value
        void _remove();

        private:

        //* list
        TreeView& _list() const
        { return *list_; }

        //* model
        AlarmModel model_;

        //* alarm list
        TreeView* list_ = nullptr;

        //* edit button
        QPushButton* edit_ = nullptr;

        //* remove button
        QPushButton* remove_ = nullptr;

        //* remove action
        QAction* removeAction_ = nullptr;

    };

}

#endif
