/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CpuLoad.h"
#include "CpuMenu.h"
#include "Debug.h"
#include "IconEngine.h"

namespace Cpu
{
    //_____________________________________________________
    CpuMenu::CpuMenu( const QString& name, QWidget* parent ):
        QMenu( name, parent ),
        Counter( "CpuMenu" )
    {

        Debug::Throw( "CpuMenu::CpuMenu.\n" );

        connect( this, SIGNAL(triggered(QAction*)), SLOT(_select(QAction*)) );
        connect( this, SIGNAL(aboutToShow()), SLOT(_update()) );

        actionGroup_ = new QActionGroup( this );
        actionGroup_->setExclusive( true );

    }

    //_____________________________________________________
    void CpuMenu::_select( QAction* action )
    {

        Debug::Throw( "CpuMenu::_select.\n" );
        const auto iter( actions_.find( action ) );
        if( iter != actions_.end() )
        {
            device_ = iter.value();
            emit deviceSelected( device_ );
        }

        return;
    }

    //_____________________________________________________
    void CpuMenu::_update()
    {
        Debug::Throw( "CpuMenu::_update.\n" );

        // clear
        clear();
        actions_.clear();

        CpuLoad load;
        load.update();

        CpuLoad::CpuNames cpuNames( load.cpuNames() );
        if( cpuNames.empty() ) cpuNames.insert( device_ );
        for( const auto& name:cpuNames )
        {
            auto action = addAction( name );
            actionGroup_->addAction( action );
            action->setCheckable( true );
            action->setChecked( device_ == name );

            actions_.insert( action, name );

        }

        return;

    }
}
