#ifndef DiskMenu_h
#define DiskMenu_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "KernelVersion.h"

#include <QMenu>
#include <QAction>

namespace Disk
{

    /**
    \class DiskMenu
    \brief customized popup menu to open a previous logbook
    */
    class DiskMenu: public QMenu, private Base::Counter<DiskMenu>
    {

        //* Qt meta object declaration
        Q_OBJECT

        public:

        //* constructor
        explicit DiskMenu( const QString& = tr( "Select Disk Device" ), QWidget* = nullptr );

        //* kernel version
        void setKernelVersion( const Main::KernelVersion& kernel )
        { kernel_ = kernel; }

        //* select disk name
        void setDevice( const QString& name )
        { device_ = name; }

        Q_SIGNALS:

        //* signal emitted when a device is selected
        void deviceSelected( QString );

        private Q_SLOTS:

        //* select disk
        void _select( QAction* );

        //* load list of disk devices and update
        void _update();

        private:

        //* kernel version
        Main::KernelVersion kernel_;

        //* selected device
        QString device_;

        //* action group
        QActionGroup* actionGroup_ = nullptr;

        //* map actions to file recors
        using ActionMap = QHash<QAction*, QString>;

        //* map actions to FileRecords
        ActionMap actions_;

    };

};

#endif
