/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "AnchorWidget.h"

#include "CppUtil.h"
#include "GridLayout.h"

#include <QLayout>
#include <QLabel>

//____________________________________________________________
AnchorWidget::AnchorWidget( QWidget* parent, GridLayout* layout ):
    QWidget( parent ),
    gridLayout_( layout )
{

    if( !gridLayout_ )
    {

        QHBoxLayout* hLayout = new QHBoxLayout;
        hLayout->setMargin(0);
        hLayout->setSpacing(0);
        setLayout( hLayout );

        gridLayout_ = new GridLayout;
        gridLayout_->setMargin(0);
        gridLayout_->setSpacing(5);
        gridLayout_->setMaxCount(2);
        gridLayout_->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
        hLayout->addLayout( gridLayout_ );
        hLayout->addStretch( 1 );

    }

    QString tooltip( tr( "The anchor defines which corner of the screen is used to store window "
        "position.\n It is usefull e.g. when using the same configuration for different "
        "screen resolutions" ) );

    QLabel* label;
    gridLayout_->addWidget( label = new QLabel( tr( "Vertical Anchor:" ), this ) );
    gridLayout_->addWidget( verticalComboBox_ = new QComboBox( this ) );
    verticalComboBox_->addItems( Base::makeT<QStringList>({
        Anchor::verticalAlignmentName( Anchor::Top ),
        Anchor::verticalAlignmentName( Anchor::Bottom ),
        Anchor::verticalAlignmentName( Anchor::VerticalCenter ) }) );
    verticalComboBox_->setToolTip( tooltip );
    label->setBuddy( verticalComboBox_ );

    gridLayout_->addWidget( label = new QLabel( tr( "Hozizontal Anchor:" ), this ) );
    gridLayout_->addWidget( horizontalComboBox_ = new QComboBox( this ) );
    horizontalComboBox_->addItems( Base::makeT<QStringList>({
        Anchor::horizontalAlignmentName( Anchor::Left ),
        Anchor::horizontalAlignmentName( Anchor::Right ),
        Anchor::horizontalAlignmentName( Anchor::HorizontalCenter ) }) );
    horizontalComboBox_->setToolTip( tooltip );
    label->setBuddy( horizontalComboBox_ );

    setAnchor( Anchor::Default );

}

//____________________________________________________________
void AnchorWidget::setAnchor( Anchor::AlignmentFlags value )
{

    horizontalComboBox_->setCurrentIndex( horizontalComboBox_->findText( Anchor::horizontalAlignmentName( value ) ) );
    verticalComboBox_->setCurrentIndex( verticalComboBox_->findText( Anchor::verticalAlignmentName( value ) ) );

}

//____________________________________________________________
Anchor::AlignmentFlags AnchorWidget::anchor() const
{
    return
        Anchor::AlignmentFlags( 1<<horizontalComboBox_->currentIndex() ) |
        Anchor::AlignmentFlags( 1<<( 3+verticalComboBox_->currentIndex() ) );
}
