#ifndef ApplicationType_h
#define ApplicationType_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CommandLineParser.h"
#include "Counter.h"
#include "IconEngine.h"

#include <QHash>
#include <QIcon>
#include <QSet>
#include <QString>

class ApplicationType final:private Base::Counter<ApplicationType>
{

    public:

    //* application enumeration
    enum Type
    {
        AppNone = 0,
        AppAcpi = 1<<0,
        AppCalendar = 1<<1,
        AppClock = 1<<2,
        AppCpu = 1<<3,
        AppDisk = 1<<4,
        AppMemory = 1<<5,
        AppNetwork = 1<<6,
        AppSummary = 1<<7,
        AppTemperature = 1<<8

    };

    //* application map
    using Set = QSet<ApplicationType>;

    class Helper
    {

        public:

        //* constructor from command line
        static Set set( const CommandLineParser& );

        //* constructor from mask
        static Set set( int );

        //* cast to mask
        static int toInt( const Set& );

    };

    //* constructor
    ApplicationType( Type type ):
        Counter( "ApplicationType" ),
        type_( type )
    {}

    //* type
    Type type() const
    { return type_; }

    //* application title
    QString name() const
    { return names()[type_]; }

    //* application icon
    QString iconName() const
    { return iconNames()[type_]; }

    //* application icon
    QIcon icon() const
    { return IconEngine::get( iconName() ); }

    //* application map
    using Map=QHash<Type, QString>;

    //* map application names and type
    static const Map& names();

    //* icon map
    static const Map& iconNames();

    private:

    //* type
    Type type_ = AppNone;

};

//* equal to operator
inline bool operator == (const ApplicationType& first, const ApplicationType& second)
{ return first.type() == second.type(); }

//* less than operator
inline bool operator < (const ApplicationType& first, const ApplicationType& second)
{ return first.type() < second.type(); }

inline uint qHash( const ApplicationType& type )
{ return qHash( type.type() ); }

#endif
