#ifndef GeometryCalculationObject_h
#define GeometryCalculationObject_h
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ApplicationData.h"
#include "Counter.h"

//* encapsulate geometry calculations
class GeometryCalculationObject final: private Base::Counter<GeometryCalculationObject>
{

    public:

    //* constructor
    explicit GeometryCalculationObject():
        Counter( "GeometryCalculationObject" )
        {}

    //*@name accessors
    //@{

    //* get updated application list
    const ApplicationData::List& applications() const
    { return applications_; }

    //@}

    //*@name modifiers
    //@{

    //* set application list
    void setApplications( const ApplicationData::List& applications )
    { applications_ = applications; }

    //* desktop geometry
    void setDesktopGeometry( const QRect& desktopGeometry )
    { desktopGeometry_ = desktopGeometry; }

    //* calculate
    void calculate();

    //@}

    private:

    //* application data list
    ApplicationData::List applications_;

    //* desktop geometry
    QRect desktopGeometry_;

};

#endif
