/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "MainWindow.h"

#include "Application.h"
#include "BaseContextMenu.h"
#include "IconEngine.h"
#include "IconNames.h"
#include "Singleton.h"
#include "BaseToolTipWidget.h"
#include "XmlOptions.h"

//_________________________________________________________________
MainWindow::MainWindow( QWidget* parent ):
    TransparentWindow( parent )
{
    Debug::Throw( "MainWindow::MainWindow.\n" );
    _installActions();
}

//_______________________________________________
bool MainWindow::event(QEvent *event)
{

    if (event->type() == QEvent::ToolTip )
    {

        // cast event
        QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);

        if( _updateToolTip( helpEvent->pos() ) || _updateToolTip() )
        {
            toolTipWidget_->adjustSize();
            toolTipWidget_->setIndexRect( QRect( static_cast<QHelpEvent*>(event)->globalPos(), QSize( 1, 1 ) ) );
            toolTipWidget_->show();
        }

    }

    return TransparentWindow::event(event);

}

//_______________________________________________________
void MainWindow::timerEvent( QTimerEvent* event )
{

    if( event->timerId() == updateTimer_.timerId() )
    {

        if( toolTipWidget_ && !toolTipWidget_->isHidden() )
        {
            Debug::Throw( "MainWindow::timerEvent - updating tooltip.\n" );
            _updateToolTip();
        }

    } else return TransparentWindow::timerEvent( event );

}

//___________________________________________________
void MainWindow::mousePressEvent( QMouseEvent *event )
{
    if( toolTipWidget_ ) toolTipWidget_->hide();
    TransparentWindow::mousePressEvent( event );
}

//___________________________________________________
void MainWindow::mouseDoubleClickEvent( QMouseEvent *event )
{
    TransparentWindow::mouseDoubleClickEvent( event );
   if( event->button() == Qt::LeftButton ) _raiseAllAction().trigger();
    return;
}

//__________________________________________________________
BaseToolTipWidget* MainWindow::_toolTipWidget()
{
    if( !toolTipWidget_ ) toolTipWidget_ = _createToolTipWidget();
    return toolTipWidget_;
}

//__________________________________________________________
BaseToolTipWidget* MainWindow::_createToolTipWidget()
{ return nullptr; }

//________________________________________________
void MainWindow::_installContextMenuActions( BaseContextMenu* menu )
{

    Debug::Throw( "MainWindow::_installContextMenuActions.\n" );
    TransparentWindow::_installContextMenuActions( menu );
    menu->addAction( closeAllAction_ );

}

//________________________________________________
void MainWindow::_updateConfiguration()
{

    Debug::Throw( "MainWindow::_updateConfiguration.\n" );
    TransparentWindow::_updateConfiguration();

    // refresh
    refresh_ = XmlOptions::get().get<int>( "REFRESH_RATE" );

}

//________________________________________________
void MainWindow::_installActions()
{

    Debug::Throw( "MainWindow::_installActions.\n" );

    // raise all
    addAction( raiseAllAction_ = new QAction( IconEngine::get( IconNames::RaiseAll ), tr( "Raise All" ), this ) );
    raiseAllAction_->setToolTip( tr( "Raise all transparent windows" ) );
    connect( raiseAllAction_, SIGNAL(triggered()), Base::Singleton::get().application(), SLOT(sendRaiseRequest()) );

    // close all
    addAction( closeAllAction_ = new QAction( IconEngine::get( IconNames::Exit ), tr( "Exit" ), this ) );
    closeAllAction_->setToolTip( tr( "Exit all transparent applications" ) );
    closeAllAction_->setShortcut( QKeySequence::Quit );
    connect( closeAllAction_, SIGNAL(triggered()), Base::Singleton::get().application(), SLOT(sendCloseRequest()) );

}
