/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "XcbThread.h"

#include "Debug.h"
#include "XcbConnection.h"
#include "XcbUtil.h"

#include <QMetaType>

#if WITH_XCB
#include <xcb/xcb.h>
#endif

//______________________________________________________
XcbThread::XcbThread( QObject* parent ):
    QThread( parent ),
    Counter( "XcbThread" )
{
    Debug::Throw( "XcbThread::XcbThread.\n" );
    qRegisterMetaType<WId>( "WId" );
    qRegisterMetaType<uint32_t>( "uint32_t" );
}

//______________________________________________________
void XcbThread::run()
{

    if( !windowId_ ) return;

    #if WITH_XCB
    // need to create new connection, get screen etc.
    // in order not to interfere with Qt event loop
    XcbConnection connection;
    if( !connection.get() ) return;

    // select events
    uint32_t mask = XCB_CW_EVENT_MASK;
    uint32_t values[1] = { XCB_EVENT_MASK_PROPERTY_CHANGE };
    xcb_change_window_attributes_checked(connection, windowId_, mask, values);
    xcb_flush(connection);

    // loop over events
    while( auto event = XcbUtil::ScopedPointer<xcb_generic_event_t>( xcb_wait_for_event( connection ) ) )
    {

        if( ( event->response_type & ~0x80 ) == XCB_PROPERTY_NOTIFY )
        {
            // cast event
            auto propertyEvent = reinterpret_cast<xcb_property_notify_event_t*>( event.get() );
            auto atom = propertyEvent->atom;

            if( atom == *XcbUtil::get().atom<xcb_atom_t>( XcbDefines::_NET_WM_STATE ) ) {

                emit stateChanged( windowId_ );

            } else if( atom == *XcbUtil::get().atom<xcb_atom_t>( XcbDefines::_NET_WM_DESKTOP ) ) {

                // get cardinal
                uint32_t desktop = XcbUtil::get().cardinal( windowId_, XcbDefines::_NET_WM_DESKTOP );
                emit desktopChanged( windowId_, desktop );

            }

        }

    }

    #endif

}
