#ifndef NetworkMonitor_h
#define NetworkMonitor_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "NetworkLoad.h"
#include "NetworkMenu.h"

#include <QBasicTimer>
#include <QObject>
#include <QTimerEvent>

class SystemNotifications;

namespace Network {

    class NetworkMonitor: public QObject, private Base::Counter<NetworkMonitor>
    {


        //* Qt meta object functions
        Q_OBJECT

        public:

        //* constructor
        explicit NetworkMonitor( QObject* = nullptr );

        //*@name accessors
        //@{

        //* network menu
        NetworkMenu& menu() const
        { return *networkMenu_; }

        //* device
        QString device() const
        { return device_; }

        // network data
        NetworkLoad::DataList data() const
        { return networkLoad_.data( device_ ); }

        //@}

        //*@name modifiers
        //@{

        //* update
        void update()
        { networkLoad_.update(); }

        //* data size
        void setDataSize( int value )
        { networkLoad_.setDataSize( value ); }

        //@}

        protected:

        //*@name event handlers
        //@{

        //* timer
        void timerEvent( QTimerEvent* ) override;

        //@}


        private Q_SLOTS:

        //* select device from menu
        void _selectDeviceFromMenu( QString );

        //* select device automatically
        void _selectAutomaticDevice();

        //* update configuration
        void _updateConfiguration();

        private:

        //* check whether current device is active and select one if not
        void _checkDevice( QString = QString() );

        //* changes current network name
        void _selectDevice( QString );

        //* popup menu for network device
        NetworkMenu* networkMenu_ = nullptr;

        //* network load probe
        NetworkLoad networkLoad_;

        //* system notifications
        SystemNotifications* systemNotifications_ = nullptr;

        //* update device timer
        QBasicTimer deviceTimer_;

        //* device
        QString device_;

    };

}

#endif
