#ifndef PictureParser_h
#define PictureParser_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"
#include "File.h"
#include "PictureAttributes.h"
#include "XmlError.h"

namespace Pictures
{

  //! job parser based on Xml
  class PictureParser final: private Base::Counter<PictureParser>
  {

    public:

    //! constructor
    explicit PictureParser():
      Counter( "PictureParser" )
      {}

    //! read from a file
    bool read( const File& file );

    //! write to file
    bool write( const File& file ) const;

    //! add attributes
    void addAttributes( const PictureAttributes& attributes )
    { attributesList_ << attributes; }

    //! get attributes
    const PictureAttributes::List& attributes()
    {
      if( !attributesList_.size() ) attributesList_ << PictureAttributes();
      return attributesList_;
    }

    //! Xml error
    const XmlError& xmlError() const
    { return error_; }

    private:

    //! xml error message, if any
    XmlError error_;

    //! list of all read PictureAttributes
    PictureAttributes::List attributesList_;

  };

};

#endif
