/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "XmlOptions.h"
#include "Util.h"
#include "File.h"
#include "KernelVersion.h"
#include "SummaryWidget.h"

//! Default options installer
void installSummaryOptions()
{

    XmlOptions::get().setAutoDefault( true );
    XmlOptions::get().set( "ADJUST_TIME_CMD", "Undefined" );
    XmlOptions::get().set( "CPU_NAME", "cpu" );
    XmlOptions::get().set( "DISK_DEVICE", "hda" );
    XmlOptions::get().set( "PROBE_NAME", "CPU" );
    XmlOptions::get().set( "ACPI_FILE", "/proc/acpi/thermal_zone/THM/temperature" );

    // automatic network selection
    XmlOptions::get().set( "NETWORK_DEVICE", "eth0" );
    XmlOptions::get().set<bool>( "NETWORK_AUTO_SELECT", true );
    XmlOptions::get().set<int>( "NETWORK_AUTO_SELECT_RATE", 10 );

    XmlOptions::get().set<bool>( "ALWAYS_USE_CMD", false );
    XmlOptions::get().set<int>( "REFRESH_RATE", 1 );
    XmlOptions::get().set<int>( "CLOCK_DELAY", 0 );
    XmlOptions::get().set<int>( "KERNEL_VERSION", Main::Linux26 );

    // temperature
    XmlOptions::get().set<bool>( "USE_LM_SENSORS", true );

    XmlOptions::get().set<int>( "SAMPLES", 10 );
    XmlOptions::get().set<int>( "DISPLAY_MASK",
        Summary::SummaryWidget::Host|
        Summary::SummaryWidget::Date|
        Summary::SummaryWidget::Time|
        Summary::SummaryWidget::Cpu|
        Summary::SummaryWidget::Memory|
        Summary::SummaryWidget::Disk|
        Summary::SummaryWidget::Temperature|
        Summary::SummaryWidget::Acpi );

    // resource file
    XmlOptions::get().set( "OLD_RC_FILE", Option( File(".transparent-summaryrc").addPath( Util::home() ), Option::Flag::None ) );
    XmlOptions::get().set( "RC_FILE", Option( File("transparent-summaryrc").addPath( Util::config() ), Option::Flag::None ) );

    XmlOptions::get().setAutoDefault( false );

}
