#ifndef TemperatureMonitor_h
#define TemperatureMonitor_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Temperature.h"
#include "TemperatureMenu.h"

#include <QObject>

namespace Temperature
{

    //* transparent temperature load widget
    class TemperatureMonitor: public QObject, private Base::Counter<TemperatureMonitor>
    {

        Q_OBJECT

        public:

        //* constructor
        explicit TemperatureMonitor( QObject* = nullptr );

        //*@name accessors
        //@{

        //* menu
        TemperatureMenu& menu() const
        { return *temperatureMenu_; }

        //* device
        QString device() const
        { return temperature_.useSensors() ? device_:QString(); }

        //* use sensors
        bool useSensors() const
        { return temperature_.useSensors(); }

        // data
        Temperature::DataList data() const
        { return temperature_.data( device_ ); }

        //@}

        //*@name modifiers
        //@{

        //* update
        void update()
        {
            temperatureMenu_->setDevices( temperature_.probeNames() );
            temperature_.update();
        }

        //* data size
        void setDataSize( int value )
        { temperature_.setDataSize( value ); }

        //@}

        private Q_SLOTS:

        //* changes current cpu name
        void _selectDevice( QString );

        //* configuration
        void _updateConfiguration();

        private:

        //* popup menu for cpu name
        TemperatureMenu* temperatureMenu_ = nullptr;

        //* temperature load probe
        Temperature temperature_;

        //* probe name to display
        QString device_;

    };

}

#endif
